# Small Samus Considerations (0.3 size modifier)

- Some players report getting nauseated

- If you unmorph right as you bonk against a ceiling, you will clip through it. Don't do this on accident, but definitely do it on purpose ^_^
    - Keep in mind, if you are in HAT without gravity suit, you will clip OoB if you simply unmorph

- You need to jump through the large frigate doors to properly transition the room. If you do not, the textures will disapear around you and you will have to turn around. Be extra careful of this during frigate escape because some doors lock behind you.

- It is very easy to die in the central dynamo maze, use bomb jump to update the camera if it does not follow you. Walking through the maze is safter than rolling through it.

- Life grove spinner manip doesn't work (use OoB clip and pick up from under map instead)

- Early wild doesn't work (use floaty instead, or boost clip through the vines in the front entrance)

- Spiderless shaft BSJ doesn't work (use OoB clip instead)

- Trying to enter Elite Quarters from PCA by walking under the bars will crash the game. The workaround is to walk under the bars, scan the bars away, then reload the room.

- It's possible to get stuck in the corners of the gereric connecting rooms in Chozo while in morph ball. To get out, wait a couple seconds to drop onto the floor, then roll back out away from the corner along the wall.

- You can accidentally fall OoB through the floor in MQB, Security Access A, Security Access B, Control Tower elevators, and probably a few others
